<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Επιλέξτε μια εφαρμογή</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Εγκατεστημένες εφαρμογές</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Προσαρμοσμένη εντολή</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Γραμμή εντολών προς εκτέλεση:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Όνομα της εφαρμογής:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Αυτοί οι ειδικοί κωδικοί μπορούν να χρησιμοποιηθούν στη γραμμή εντολών:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Αναπαριστά ένα όνομα αρχείου&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Αναπαριστά πολλαπλά ονόματα αρχείων&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Αναπαριστά ένα URI του αρχείου&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Αναπαριστά πολλαπλά URI&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Διατήρηση του παραθύρου του τερματικού ανοιχτό μετά την εκτέλεση της εντολής</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Εκτέλεση στον προσομοιωτή τερματικού</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Ορίστε την επιλεγμένη εφαρμογή ως την εξ ορισμού ενέργεια για αυτού του τύπου αρχεία</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Επεξεργασία σελιδοδεικτών</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Τοποθεσία</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Προσθήκη αντικειμένου</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Αφαίρεση αντικειμένου</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Χρησιμοποιήστε τη μεταφορά και απόθεση για αναδιάταξη των αντικειμένων</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Εκτέλεση του αρχείου</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>Ά&amp;νοιγμα</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>&amp;Εκτέλεση</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Εκτέλεση στο &amp;τερματικό</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Διαδρομή:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Όνομα αρχείου:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>Τύπος αρχείου:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Προορισμός:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Επεξεργασία:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Προετοιμασία...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Πρόοδος</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Υπολειπόμενος χρόνος:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>Επεξεργασμένα αρχεία:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Ιδιότητες του αρχείου</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Τοποθεσία:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Τύπος αρχείου:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Τύπος Mime:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Μέγεθος αρχείου:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Μέγεθος στον δίσκο:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Τελευταία τροποποίηση:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Προορισμός συνδέσμου:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Άνοιγμα με:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Τελευταία προσπέλαση:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="281"/>
        <source>Contains:</source>
        <translation>Περιέχει:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="336"/>
        <source>Device Usage:</source>
        <translation>Χρήση συσκευής:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="346"/>
        <source>Permissions</source>
        <translation>Άδειες</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Ownership</source>
        <translation>Ιδιοκτησία</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="385"/>
        <location filename="../file-props.ui" line="450"/>
        <location filename="../file-props.ui" line="564"/>
        <source>Group:</source>
        <translation>Ομάδα:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="398"/>
        <location filename="../file-props.ui" line="433"/>
        <location filename="../file-props.ui" line="512"/>
        <source>Owner:</source>
        <translation>Ιδιοκτήτης:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Access Control</source>
        <translation>Έλεγχος πρόσβασης</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="467"/>
        <location filename="../file-props.ui" line="616"/>
        <source>Other:</source>
        <translation>Άλλο:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="484"/>
        <source>Make the file executable</source>
        <translation>Ορισμός ως εκτελέσιμο</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="525"/>
        <location filename="../file-props.ui" line="577"/>
        <location filename="../file-props.ui" line="629"/>
        <source>Read</source>
        <translation>Ανάγνωση</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="538"/>
        <location filename="../file-props.ui" line="590"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Write</source>
        <translation>Εγγραφή</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="551"/>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <source>Execute</source>
        <translation>Εκτέλεση</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="664"/>
        <source>Sticky</source>
        <translation>Κολλημένο</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="671"/>
        <source>SetUID</source>
        <translation>Καθορισμός του UID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="678"/>
        <source>SetGID</source>
        <translation>Καθορισμός του GID</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="714"/>
        <source>Advanced Mode</source>
        <translation>Προηγμένη λειτουργία</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Προσαρμοσμένο</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="263"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Επιλέξτε μια εφαρμογή για το άνοιγμα των αρχείων «%1»</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Φάκελος</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Κενό αρχείο</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>Ο κατάλογος &apos;%1&apos; δεν είναι έγκυρος</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Φόρτωση...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Κανένας υποφάκελος&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="213"/>
        <source>Open in New T&amp;ab</source>
        <translation>Άνοιγμα σε νέα &amp;καρτέλα</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Άνοιγμα σε νέο &amp;παράθυρο</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="222"/>
        <source>Open in Termina&amp;l</source>
        <translation>Άνοιγμα στο &amp;τερματικό</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Αντιγραφή εδώ</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Μετακίνηση εδώ</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Δημιουργία συμβολικού δεσμού εδώ</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Νέος σελιδοδείκτης</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Το αρχείο «%1» φαίνεται να είναι ένα αρχείο επιφάνειας εργασίας.
Ποια ενέργεια θέλετε να πραγματοποιήσετε;</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Το αρχείο κειμένου «%1» φαίνεται ότι είναι ένα εκτελέσιμο σενάριο.
Τι θέλετε να κάνετε με αυτό;</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Αυτό το αρχείο «%1» είναι εκτελέσιμο. Θέλετε να το εκτελέσετε;</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="109"/>
        <source>Go Back</source>
        <translation>Μετάβαση πίσω</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="110"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Αριστερά</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="116"/>
        <source>Go Forward</source>
        <translation>Μετάβαση εμπρός</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="117"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Δεξιά</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="124"/>
        <source>Reload</source>
        <translation>Επαναφόρτωση</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="125"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="142"/>
        <source>Create Folder</source>
        <translation>Δημιουργία φακέλου</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="152"/>
        <source>Icon View</source>
        <translation>Προβολή εικονιδίων</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="156"/>
        <source>Thumbnail View</source>
        <translation>Προβολή εικόνων επισκόπησης</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="160"/>
        <source>Compact View</source>
        <translation>Συμπαγής προβολή</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="164"/>
        <source>Detailed List View</source>
        <translation>Προβολή αναλυτικού κατάστιχου</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="172"/>
        <source>Icon Sizes</source>
        <translation>Μεγέθη εικονιδίου</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="174"/>
        <source>Size of big icons:</source>
        <translation>Το μέγεθος των μεγάλων εικονιδίων:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="181"/>
        <source>Size of small icons:</source>
        <translation>Το μέγεθος των μικρών εικονιδίων:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="188"/>
        <source>Size of thumbnails:</source>
        <translation>Το μέγεθος των εικόνων επισκόπησης:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="204"/>
        <source>Show Thumbnails</source>
        <translation>Εμφάνιση εικόνων επισκόπησης</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="209"/>
        <source>Show File Tooltips</source>
        <translation>Εμφάνιση υποδείξεων αρχείου</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="220"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="540"/>
        <location filename="../filedialog.cpp" line="935"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="540"/>
        <source>Please select a file</source>
        <translation>Παρακαλώ επιλέξτε ένα αρχείο</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="582"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>Το αρχείο %1 υπάρχει ήδη.
Θέλετε να το αντικαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="905"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Η διαδρομή «%1» δεν υπάρχει</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="919"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>Το «%1» δεν είναι κατάλογος</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="925"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>Το «%1» δεν είναι αρχείο</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1077"/>
        <location filename="../filedialog.cpp" line="1185"/>
        <source>&amp;Open</source>
        <translation>Ά&amp;νοιγμα</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1080"/>
        <location filename="../filedialog.cpp" line="1193"/>
        <source>&amp;Save</source>
        <translation>Απο&amp;θήκευση</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1087"/>
        <source>All Files (*)</source>
        <translation>Όλα τα αρχεία (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Open File</source>
        <translation>Άνοιγμα αρχείου</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="140"/>
        <source>Save File</source>
        <translation>Αποθήκευση αρχείου</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> εικ</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="84"/>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="88"/>
        <source>Open With...</source>
        <translation>Άνοιγμα με...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="116"/>
        <source>Other Applications</source>
        <translation>Άλλες εφαρμογές</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="122"/>
        <source>Create &amp;New</source>
        <translation>Δημιουργία &amp;νέου</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="141"/>
        <source>&amp;Restore</source>
        <translation>&amp;Επαναφορά</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="147"/>
        <source>Cut</source>
        <translation>Αποκοπή</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="151"/>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="155"/>
        <source>Paste</source>
        <translation>Επικόλληση</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="159"/>
        <location filename="../filemenu.cpp" line="407"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Μετακίνηση στα απορρίμματα</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="163"/>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="218"/>
        <source>Extract to...</source>
        <translation>Εξαγωγή σε...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Extract Here</source>
        <translation>Εξαγωγή εδώ</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="233"/>
        <source>Compress</source>
        <translation>Συμπίεση</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="242"/>
        <source>Properties</source>
        <translation>Ιδιότητες</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="253"/>
        <source>Trust selected executables</source>
        <translation>Τα επιλεγμένα εκτελέσιμα είναι έμπιστα</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Trust this executable</source>
        <translation>Το εκτελέσιμο είναι έμπιστο</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="342"/>
        <source>Output</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="407"/>
        <source>&amp;Delete</source>
        <translation>&amp;Διαγραφή</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="312"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="313"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Μερικά αρχεία δεν μπορούν να μετακινηθούν στον κάδο απορριμμάτων διότι το υποκείμενο αρχείο συστήματος δεν υποστηρίζει αυτήν την ενέργεια.
Θέλετε αντί αυτού να τα διαγράψετε;</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="399"/>
        <location filename="../fileoperation.cpp" line="417"/>
        <source>Confirm</source>
        <translation>Επιβεβαίωση</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="400"/>
        <source>Do you want to delete the selected files?</source>
        <translation>Επιθυμείτε την διαγραφή των επιλεγμένων αρχείων;</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="418"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>Επιθυμείτε την μετακίνηση των επιλεγμένων αρχείων στον κάδο απορριμμάτων;</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>Μετακίνηση των αρχείων</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Μετακίνηση των ακολούθων αρχείων στον φάκελο προορισμού:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Αντιγραφή των αρχείων</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Αντιγραφή των ακολούθων αρχείων στον φάκελο προορισμού:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Ρίψη των αρχείων στα απορρίμματα</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Μετακίνηση των ακολούθων αρχείων στον κάδο απορριμμάτων:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Διαγραφή των αρχείων</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Διαγραφή των ακολούθων αρχείων:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Δημιουργία συμβολικών δεσμών</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Δημιουργία συμβολικών δεσμών για τα ακόλουθα αρχεία:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Αλλαγή ιδιοχαρακτηριστικών</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Αλλαγή των ιδιοχαρακτηριστικών των ακολούθων αρχείων:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Επαναφορά των αρχείων από τον κάδο απορριμμάτων</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Επαναφέρονται τα παρακάτω αρχεία από τον κάδο απορριμμάτων:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="146"/>
        <location filename="../fileoperationdialog.cpp" line="152"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>Προβολή των περιεχομένων του φακέλου</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>Προβολή και τροποποίηση των περιεχομένων του φακέλου</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>Ανάγνωση</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>Ανάγνωση και εγγραφή</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>Απαγορευμένο</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>Αρχεία διαφορετικού τύπου</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <source>Multiple Files</source>
        <translation>Πολλαπλά αρχεία</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="336"/>
        <source>%p% used</source>
        <translation>%p% σε χρήση</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="337"/>
        <source>%1 Free of %2</source>
        <translation>%1 Ελεύθερα από %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="382"/>
        <source>no file</source>
        <translation>κανένα αρχείο</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="384"/>
        <source>one file</source>
        <translation>ένα αρχείο</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="386"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln αρχείο</numerusform>
            <numerusform>%Ln αρχεία</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="420"/>
        <source>Select an icon</source>
        <translation>Επιλογή εικονιδίου</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="422"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Εικόνες (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="518"/>
        <source>Apply changes</source>
        <translation>Εφαρμογή των αλλαγών</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="519"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Θέλετε να εφαρμόσετε αναδρομικά αυτές τις αλλαγές σε όλα τα αρχεία και υποφακέλους;</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>Για την αναζήτηση θα πρέπει να προσθέσετε τουλάχιστον έναν κατάλογο.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Επιλογή φακέλου</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="471"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Αδύνατη η αντιγραφή ενός καταλόγου στον εαυτό του!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="522"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Αδύνατη η δημιουργία δεσμού σε μη εγγενές σύστημα αρχείων</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="41"/>
        <source>Create &amp;New</source>
        <translation>Δημιουργία &amp;νέου</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="48"/>
        <source>&amp;Paste</source>
        <translation>Επι&amp;κόλληση</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="54"/>
        <source>Select &amp;All</source>
        <translation>Επιλογή ό&amp;λων</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="58"/>
        <source>Invert Selection</source>
        <translation>Αντιστροφή επιλογής</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="64"/>
        <source>Sorting</source>
        <translation>Ταξινόμηση</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Show Hidden</source>
        <translation>Εμφάνιση των κρυφών</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="98"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Ι&amp;διότητες του φακέλου</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="141"/>
        <source>Output</source>
        <translation>Έξοδος</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="163"/>
        <source>By File Name</source>
        <translation>Ανά όνομα αρχείου</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="164"/>
        <source>By Modification Time</source>
        <translation>Ανά χρόνο τροποποίησης</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="167"/>
        <source>By Deletion Time</source>
        <translation>Ανά χρόνο διαγραφής</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="170"/>
        <source>By File Size</source>
        <translation>Ανά μέγεθος αρχείου</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="171"/>
        <source>By File Type</source>
        <translation>Ανά τύπο αρχείου</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="172"/>
        <source>By File Owner</source>
        <translation>Ανά ιδιοκτήτη αρχείου</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="173"/>
        <source>By File Group</source>
        <translation>Ανά ομάδα αρχείων</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="179"/>
        <source>Ascending</source>
        <translation>Αύξουσα</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="184"/>
        <source>Descending</source>
        <translation>Φθίνουσα</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="201"/>
        <source>Folder First</source>
        <translation>Οι φάκελοι πρώτα</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="209"/>
        <source>Hidden Last</source>
        <translation>Τα κρυφά τελευταία</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="217"/>
        <source>Case Sensitive</source>
        <translation>Διάκριση πεζών/κεφαλαίων</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="303"/>
        <source>Location:</source>
        <translation>Τοποθεσία:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="306"/>
        <source>File type:</source>
        <translation>Τύπος αρχείου:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="310"/>
        <source>File size:</source>
        <translation>Μέγεθος αρχείου:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="314"/>
        <source>Last modified:</source>
        <translation>Τελευταία τροποποίηση:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="315"/>
        <source>Last accessed:</source>
        <translation>Τελευταία προσπέλαση:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="319"/>
        <source>Owner:</source>
        <translation>Ιδιοκτήτης:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Group:</source>
        <translation>Ομάδα:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="384"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="387"/>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="390"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="393"/>
        <source>Modified</source>
        <translation>Τροποποιήθηκε</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="396"/>
        <source>Deleted</source>
        <translation>Διεγράφη</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="399"/>
        <source>Owner</source>
        <translation>Ιδιοκτήτης</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="402"/>
        <source>Group</source>
        <translation>Ομάδα</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="373"/>
        <source>Auto-resize columns</source>
        <translation>Αυτόματη προσαρμογή μεγέθους στηλών</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="390"/>
        <source>Visible Columns</source>
        <translation>Ορατές στήλες</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Έντονα</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Πλάγια</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Σύνδεση</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="130"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Επεξεργασία της διαδρομής</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="133"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Αντιγραφή της διαδρομής</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="47"/>
        <source>Places</source>
        <translation>Τοποθεσίες</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="55"/>
        <source>Desktop</source>
        <translation>Επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="61"/>
        <source>Computer</source>
        <translation>Υπολογιστής</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="69"/>
        <source>Applications</source>
        <translation>Εφαρμογές</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="78"/>
        <source>Network</source>
        <translation>Δίκτυο</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Devices</source>
        <translation>Συσκευές</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Σελιδοδείκτες</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Απορρίμματα</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="481"/>
        <source>Open in New Tab</source>
        <translation>Άνοιγμα σε νέα καρτέλα</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="484"/>
        <source>Open in New Window</source>
        <translation>Άνοιγμα σε νέο παράθυρο</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="496"/>
        <source>Empty Trash</source>
        <translation>Άδειασμα των απορριμμάτων</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="516"/>
        <location filename="../placesview.cpp" line="573"/>
        <source>Hide</source>
        <translation>Απόκρυψη</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="533"/>
        <source>Move Bookmark Up</source>
        <translation>Μετακίνηση του σελιδοδείκτη προς τα πάνω</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="538"/>
        <source>Move Bookmark Down</source>
        <translation>Μετακίνηση του σελιδοδείκτη προς τα κάτω</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="542"/>
        <source>Rename Bookmark</source>
        <translation>Μετονομασία σελιδοδείκτη</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="545"/>
        <source>Remove Bookmark</source>
        <translation>Αφαίρεση σελιδοδείκτη</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="554"/>
        <location filename="../placesview.cpp" line="587"/>
        <source>Unmount</source>
        <translation>Αποπροσάρτηση</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="558"/>
        <source>Mount</source>
        <translation>Προσάρτηση</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="564"/>
        <source>Eject</source>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="599"/>
        <source>Show All Entries</source>
        <translation>Εμφάνιση όλων των καταχωρήσεων</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Τύπος: %1
Μέγεθος: %2
Τροποποιήθηκε: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Τύπος: %1
Τροποποιήθηκε: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Αντικατάσταση</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>&amp;Μετονομασία</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>Κατάστιχα</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>Δέντρο καταλόγων</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Αδύνατη η επαναφορά του αρχείου «%s» από τα απορρίμματα: άγνωστη αρχική διαδρομή</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Προσάρτηση</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>&amp;Ανώνυμη σύνδεση</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Σύνδεση ως &amp;χρήστης:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>Όνομα χ&amp;ρήστη:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Κωδικός πρόσβασης:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Τομέας:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>&amp;Λήθη του κωδικού πρόσβασης άμεσα</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation>Απομνημόνευση του κωδικού πρόσβασης για αυτήν &amp;την συνεδρία</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Απομνημόνευση ε&amp;σαεί</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="163"/>
        <source>Rename File</source>
        <translation>Μετονομασία αρχείου</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Please enter a new name:</source>
        <translation>Παρακαλώ εισαγάγετε ένα νέο όνομα:</translation>
    </message>
    <message>
        <location filename="../filelauncher.cpp" line="104"/>
        <location filename="../filepropsdialog.cpp" line="543"/>
        <location filename="../mountoperation.cpp" line="207"/>
        <location filename="../utilities.cpp" line="147"/>
        <location filename="../utilities.cpp" line="283"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="223"/>
        <source>Create Folder</source>
        <translation>Δημιουργία φακέλου</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="224"/>
        <source>Create File</source>
        <translation>Δημιουργία αρχείου</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="228"/>
        <source>Please enter a new file name:</source>
        <translation>Παρακαλώ εισαγάγετε ένα νέο όνομα αρχείου:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="229"/>
        <source>New text file</source>
        <translation>Νέο αρχείο κειμένου</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="233"/>
        <source>Please enter a new folder name:</source>
        <translation>Παρακαλώ εισαγάγετε ένα νέο όνομα φακέλου:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="234"/>
        <source>New folder</source>
        <translation>Νέος φάκελος</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="239"/>
        <source>Enter a name for the new %1:</source>
        <translation>Εισαγάγετε ένα όνομα για το νέο %1:</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="560"/>
        <source>Custom Icon Error</source>
        <translation>Σφάλμα προσαρμοσμένου εικονιδίου</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Η διαδρομή δεν έχει προσαρτηθεί.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="289"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Μη έγκυρο αρχείο επιφάνειας εργασίας: «%1»</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="325"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Καμία εξ ορισμού εφαρμογή για την εκτέλεση του &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="366"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Αδύνατος ο ορισμός του καταλόγου εργασίας «%1»: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="123"/>
        <source>Identifier: </source>
        <translation>Αναγνωριστικό: </translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Επιβεβαίωση αντικατάστασης των αρχείων</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Υπάρχει ήδη ένα αρχείο με το ίδιο όνομα στην συγκεκριμένη τοποθεσία.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Θέλετε να αντικαταστήσετε το υπάρχον αρχείο;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>με το παρακάτω αρχείο;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Όνομα αρχείου:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Εφαρμογή της επιλογής σε όλα τα υπάρχοντα αρχεία</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Αναζήτηση αρχείων</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Όνομα/Τοποθεσία</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Σχηματομορφές ονομάτων αρχείων:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="41"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Χρήση κανονικής έκφρασης</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="68"/>
        <source>Places to Search:</source>
        <translation>Τοποθεσίες προς αναζήτηση:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="81"/>
        <source>&amp;Add</source>
        <translation>&amp;Προσθήκη</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="93"/>
        <source>&amp;Remove</source>
        <translation>Α&amp;φαίρεση</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="129"/>
        <source>Search for hidden files</source>
        <translation>Αναζήτηση για κρυφά αρχεία</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="140"/>
        <source>File Type</source>
        <translation>Τύπος αρχείου</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="146"/>
        <source>Only search for files of following types:</source>
        <translation>Αναζήτηση αρχείων μόνο για τους ακόλουθους τύπους:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="152"/>
        <source>Text files</source>
        <translation>Αρχεία κειμένου</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="159"/>
        <source>Image files</source>
        <translation>Αρχεία εικόνων</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="166"/>
        <source>Audio files</source>
        <translation>Αρχεία ήχου</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="173"/>
        <source>Video files</source>
        <translation>Αρχεία βίντεο</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="180"/>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="187"/>
        <source>Folders</source>
        <translation>Φάκελοι</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="211"/>
        <source>Content</source>
        <translation>Περιεχόμενο</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="217"/>
        <source>File contains:</source>
        <translation>Αρχεία που περιέχουν:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Χρήση κανονικής έκφρασης</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="260"/>
        <source>Properties</source>
        <translation>Ιδιότητες</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="266"/>
        <source>File Size:</source>
        <translation>Μέγεθος αρχείου:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="295"/>
        <source>Larger than:</source>
        <translation>Μεγαλύτερο από:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="309"/>
        <location filename="../filesearch.ui" line="339"/>
        <source>Bytes</source>
        <translation>Byte</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="314"/>
        <location filename="../filesearch.ui" line="344"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="319"/>
        <location filename="../filesearch.ui" line="349"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="324"/>
        <location filename="../filesearch.ui" line="354"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="274"/>
        <source>Smaller than:</source>
        <translation>Μικρότερο από:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="48"/>
        <source>Case sensitive</source>
        <translation>Διάκριση πεζών/κεφαλαίων</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="122"/>
        <source>Search in subdirectories</source>
        <translation>Αναζήτηση σε υποκαταλόγους</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="226"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Διάκριση &amp;πεζών/κεφαλαίων</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="370"/>
        <source>Last Modified Time:</source>
        <translation>Χρόνος της τελευταίας τροποποίησης:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="378"/>
        <source>Earlier than:</source>
        <translation>Προγενέστερα από:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Later than:</source>
        <translation>Αργότερα από:</translation>
    </message>
</context>
</TS>
